# `recon.validation`

`recon.validation` provides a set of utility functions to fix and validate annotations to ensure consistency and no overlapping entities are set.
These functions are useful to run before any of the functionality in `recon.insights` or `recon.stats`.

---
## API

### **`json_to_examples`**

::: recon.validation.json_to_examples
    :docstring:

### **`fix_annotations_format`**

::: recon.validation.fix_annotations_format
    :docstring:

### **`filter_overlaps`**

::: recon.validation.filter_overlaps
    :docstring:
